@@ -4,10 +4,20 @@ bw.gwr<-function(formula, data, approach="CV",kernel="bisquare",adaptive=FALSE,
                 longlat=F,dMat,parallel.method=F,parallel.arg=NULL)
 {
   ##Data points{
-  if (is(data, "Spatial"))
+  if(inherits(data, "Spatial"))
   {
-    dp.locat<-coordinates(data)
-    data <- as(data, "data.frame")
+    if (is(data, "Spatial"))
+    {
+     dp.locat<-coordinates(data)
+     data <- as(data, "data.frame")
+    }
+  }
+  else if(inherits(data, "sf"))
+  {
+    if(any((st_geometry_type(data)=="POLYGON")) | any(st_geometry_type(data)=="MULTIPOLYGON"))
+      dp.locat <- st_coordinates(st_centroid(st_geometry(data)))
+    else
+      dp.locat <- st_coordinates(st_geometry(data))
   }
   else
   {
