@@ -51,21 +51,40 @@ gwr.basic <- function(formula, data, regression.points, bw, kernel="bisquare", a
   p4s <- as.character(NA)
   #####Check the given data frame and regression points
   #####Regression points
+  ## deal with the sf object
+  spdf <- FALSE
+  sf.poly <- FALSE
+  if(inherits(data, "Spatial"))
+     spdf <- TRUE
+  else if(any((st_geometry_type(data)=="POLYGON")) | any(st_geometry_type(data)=="MULTIPOLYGON"))
+     sf.poly <- TRUE
   if (missing(regression.points))
   {
   	rp.given <- FALSE
     regression.points <- data
-    rp.locat <- coordinates(data)
+    if(spdf)
+       rp.locat <- coordinates(data)
+    else if(sf.poly)
+       rp.locat <- st_coordinates(st_centroid(st_geometry(data)))
+    else
+       rp.locat <- st_coordinates(st_geometry(data))
     hatmatrix <- T
   }
   else
   {
     rp.given <- TRUE
     hatmatrix<-F
-    if (is(regression.points, "Spatial"))
+    if (inherits(regression.points, "Spatial"))
     {
        rp.locat<-coordinates(regression.points)
     }
+    else if (inherits(regression.points, "sf"))
+    {
+      if (any((st_geometry_type(regression.points)=="POLYGON")) | any(st_geometry_type(regression.points)=="MULTIPOLYGON"))
+         rp.locat <- st_coordinates(st_centroid(st_geometry(regression.points)))
+      else
+         rp.locat<- st_coordinates(st_centroid(st_geometry(regression.points)))
+    }
     else if (is.numeric(regression.points) && dim(regression.points)[2] == 2)
        rp.locat<-regression.points
     else
@@ -76,17 +95,27 @@ gwr.basic <- function(formula, data, regression.points, bw, kernel="bisquare", a
   }
   #Regression data is gridded or not
   griddedObj <- F
-  if(is(regression.points, "Spatial")) {
-    if (is(regression.points, "SpatialPolygonsDataFrame")) polygons<-polygons(regression.points)
+  if(inherits(regression.points, "Spatial")) {
+    if (inherits(regression.points, "SpatialPolygonsDataFrame")) polygons<-polygons(regression.points)
     else griddedObj <- gridded(regression.points)
   }
   ##Data points{
-  if (is(data, "Spatial")) {
+  if(spdf)
+  {
     p4s <- proj4string(data)
     dp.locat<-coordinates(data)
     data <- as(data, "data.frame")
-  } else {
-    stop("Given regression data must be Spatial*DataFrame")
+  }
+  else if (inherits(data, "sf"))
+  {
+    p4s <- st_crs(data)$proj4string
+    if(sf.poly)
+      dp.locat <- st_coordinates(st_centroid(st_geometry(data)))
+    else
+      dp.locat <- st_coordinates(st_geometry(data))
+  }
+  else {
+    stop("Given regression data must be a Spatial*DataFrame or sf object")
   }
 
   ####################
@@ -285,7 +314,7 @@ gwr.basic <- function(formula, data, regression.points, bw, kernel="bisquare", a
     enp <- diags[4]
     gw.R2 <- diags[6]
     gwR2.adj <- diags[7]
-	BIC <- diags[8]
+	  BIC <- diags[8]
     GW.diagnostic <- list(RSS.gw = RSS.gw, AIC = AIC, AICc = AICc, enp = enp, edf = edf, gw.R2 = gw.R2, gwR2.adj = gwR2.adj, BIC=BIC)
     ######Parameters returned for F tests
     Ftests<-list()
@@ -354,20 +383,29 @@ gwr.basic <- function(formula, data, regression.points, bw, kernel="bisquare", a
   }
   rownames(rp.locat)<-rownames(gwres.df)
 
-  if (is(regression.points, "SpatialPolygonsDataFrame"))
+  if(inherits(regression.points, "Spatial")) 
   {
-     polygons<-polygons(regression.points)
-     #SpatialPolygons(regression.points)
-     rownames(gwres.df) <- sapply(slot(polygons, "polygons"),
+    if (inherits(regression.points, "SpatialPolygonsDataFrame"))
+    {
+       polygons<-polygons(regression.points)
+       #SpatialPolygons(regression.points)
+       rownames(gwres.df) <- sapply(slot(polygons, "polygons"),
                           function(i) slot(i, "ID"))
-     SDF <-SpatialPolygonsDataFrame(Sr=polygons, data=gwres.df,match.ID=F)
+       SDF <-SpatialPolygonsDataFrame(Sr=polygons, data=gwres.df,match.ID=F)
+    }
+   else
+    {
+      SDF <- SpatialPointsDataFrame(coords=rp.locat, data=gwres.df, proj4string=CRS(p4s), match.ID=F)
+      if(griddedObj)
+          gridded(SDF) <- T
+    }
+  } 
+  else if(inherits(regression.points, "sf"))
+  {
+     SDF <- st_sf(gwres.df, geometry = st_geometry(regression.points))
   }
   else
-  {
      SDF <- SpatialPointsDataFrame(coords=rp.locat, data=gwres.df, proj4string=CRS(p4s), match.ID=F)
-     if(griddedObj)
-        gridded(SDF) <- T
-  }
   timings[["stop"]] <- Sys.time()
  ##############
   res<-list(GW.arguments=GW.arguments,GW.diagnostic=GW.diagnostic,lm=lms,SDF=SDF,
@@ -462,7 +500,10 @@ print.gwrm<-function(x, ...)
      }
 
 	cat("\n   ****************Summary of GWR coefficient estimates:******************\n")
-		df0 <- as(x$SDF, "data.frame")[,1:var.n, drop=FALSE]
+		if(inherits(x$SDF, "Spatial"))
+       df0 <- as(x$SDF, "data.frame")[,1:var.n, drop=FALSE]
+    else
+       df0 <- st_drop_geometry(x$SDF)[,1:var.n, drop=FALSE]
         if (any(is.na(df0))) {
             df0 <- na.omit(df0)
             warning("NAs in coefficients dropped")
@@ -757,13 +798,23 @@ test.gwr.par<-function(formula, data, regression.points, bw, kernel = "bisquare"
         rp.given <- TRUE
         hatmatrix <- F
     }
-    if (is(data, "Spatial")) {
-        p4s <- proj4string(data)
-        dp.locat <- coordinates(data)
-        data <- as(data, "data.frame")
+  if(inherits(data, "Spatial"))
+  {
+    if (is(data, "Spatial"))
+    {
+     dp.locat<-coordinates(data)
+     data <- as(data, "data.frame")
     }
+  }
+  else if(inherits(data, "sf"))
+  {
+    if(any((st_geometry_type(data)=="POLYGON")) | any(st_geometry_type(data)=="MULTIPOLYGON"))
+      dp.locat <- st_coordinates(st_centroid(st_geometry(data)))
+    else
+      dp.locat <- st_coordinates(st_geometry(data))
+  }
     else {
-        stop("Given regression data must be Spatial*DataFrame")
+        stop("Given regression data must be a Spatial*DataFrame or sf object")
     }
     mf <- match.call(expand.dots = FALSE)
     m <- match(c("formula", "data"), names(mf), 0)
