@@ -1,12 +1,13 @@
 gwr.robust<-function(formula, data, bw,filtered=FALSE, kernel = "bisquare", adaptive = FALSE, p = 2, theta = 0, longlat = F, dMat, F123.test = F,
-                     maxiter=20,cut.filter= 3,cut1=2,cut2=3,delta=1.0e-5) 
+                     maxiter=20,cut.filter= 3,cut1=2,cut2=3,delta=1.0e-5, parallel.method = FALSE, 
+					  parallel.arg = NULL) 
     {    	   
     	W.vect<-NULL 	
-    	res1<- gwr.basic(formula=formula, data=data, bw=bw, kernel=kernel, adaptive=adaptive, p=p, theta=theta, longlat=longlat, dMat=dMat, F123.test=F123.test, cv=T,W.vect=W.vect)
+    	res1<- gwr.basic(formula=formula, data=data, bw=bw, kernel=kernel, adaptive=adaptive, p=p, theta=theta, longlat=longlat, dMat=dMat, F123.test=F123.test, cv=T,W.vect=W.vect, parallel.method = parallel.method, parallel.arg = parallel.arg)
     	if(filtered==TRUE){
     		W.vect<-as.numeric(abs(res1$SDF$Stud_residual)<cut.filter)
     		
-    	  	res1<-gwr.basic(formula=formula, data=data, bw=bw, kernel=kernel, adaptive=adaptive, p=p, theta=theta, longlat=longlat, dMat=dMat, F123.test=F123.test, cv=T,W.vect=W.vect)
+    	  	res1<-gwr.basic(formula=formula, data=data, bw=bw, kernel=kernel, adaptive=adaptive, p=p, theta=theta, longlat=longlat, dMat=dMat, F123.test=F123.test, cv=T,W.vect=W.vect,parallel.method = parallel.method, parallel.arg = parallel.arg)
     	}
     	
     	else{ # Automatic approach
@@ -31,7 +32,7 @@ gwr.robust<-function(formula, data, bw,filtered=FALSE, kernel = "bisquare", adap
     
     		while(diffmse>delta & iter<maxiter) {
    		 	old.mse<-mse
-			res1<- gwr.basic(formula=formula, data=data, bw=bw, kernel=kernel, adaptive=adaptive, p=p, theta=theta, longlat=longlat, dMat=dMat, F123.test=F123.test, cv=T,W.vect=W.vect)
+			res1<- gwr.basic(formula=formula, data=data, bw=bw, kernel=kernel, adaptive=adaptive, p=p, theta=theta, longlat=longlat, dMat=dMat, F123.test=F123.test, cv=T,W.vect=W.vect, parallel.method = parallel.method, parallel.arg = parallel.arg)
     	
     			err<-res1$SDF$residual 
     			mse<- sum(err*err)/length(err)
